@@ -6,7 +6,7 @@ from selenium.webdriver.common.proxy import Proxy, ProxyType
 from selenium.webdriver.common.keys import Keys
 
 import socket
-from os import path
+from os import path, devnull
 import subprocess
 from .exceptions import SeleniumServerError, BrowserDeathError
 from urllib2 import URLError
@@ -15,22 +15,27 @@ import pydoc
 
 class _Selenium():
     def __init__(self, server):
-        self.selenium = subprocess.Popen(["java", "-jar", server])
+        with open(devnull, "w") as fnull:
+            self.selenium = subprocess.Popen(["java", "-jar", server],
+                stdout=fnull, stderr=fnull)
         import time
-        time.sleep(1) # There has to be a better way!
-    
+        time.sleep(2) # There has to be a better way!
+
     def kill(self):
         self.selenium.terminate()
-        if not self.selenium.poll:
-            self.selenium.kill()
+        self.selenium.kill()
 
 class Selenate():
     ''' Initiate a Selenate Object which is secretly a selenium object, A proxy
     can be supplied if so desired otherwise will run locally. Also unless 
     specified Selenate will be a firefox browser.'''
     def __init__(self, host="127.0.0.1", server="./selenium-server.jar"):
-        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        port = sock.connect_ex(("127.0.0.1", 4444)) == 0
+        try:
+            sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+            port = sock.connect_ex(("127.0.0.1", 4444)) == 0
+        except:
+            port = True # Assume it's started if sock errors out
+
         if server and path.isfile(server) and not port:
             self.selenium = _Selenium(server)
 
@@ -48,7 +53,7 @@ class Selenate():
         except URLError:
             raise SeleniumServerError
 
-    ''' find an element by a variety of locators, using the format
+    ''' Find an element by a variety of locators, using the format
     "type=locator" (ie "id=some_identifier") ''' 
     def find_element_by_locator(self, locator):
         if "=" in locator:
@@ -67,26 +72,26 @@ class Selenate():
         else:
             return "Unkown locator type"
 
-    ''' have the browser go to some url '''
+    ''' Have the browser go to some url '''
     def get(self, link):
         self.driver.get(link)
 
-    ''' wait for a locator to be displayed before continuing, or timeout if this
+    ''' Wait for a locator to be displayed before continuing, or timeout if this
     takes more than timeout seconds '''
     def wait_for(self, locator, timeout=10):
         w = WebDriverWait(self.driver, timeout)
         w.until(lambda driver: 
                 self.driver.find_element_by_locator(locator).is_displayed())
 
-    ''' click on an element identified by locator on the page '''
+    ''' Click on an element identified by locator on the page '''
     def click(self, locator):
         self.find_element_by_locator(locator).click()
 
-    ''' type text into a locator '''
+    ''' Type text into a locator '''
     def type_to(self, locator, text):
         self.find_element_by_locator(locator).send_keys(text)
 
-    ''' exit the browser '''
+    ''' Exit the browser '''
     def quit(self):
         try:
             self.driver.quit()
